*******************************
*******************************
***Florida Sibling Spillover***
***Data Cleanup****************
***Jennifer Heissel************
***July 22, 2015***************
*******************************
*******************************

set more off

use "C:\Users\jah970\Documents\Sibling Spillover\data\county_families_for_heissel_updated_june2016.dta" , clear

***to match to numbers from Fl county:
*gen mom_timeframe=1 if school_year_parent>=1998& school_year_parent<=2000&testyear== school_year_birth_parent
*replace mom_timeframe=0 if mom_timeframe==.
*keep if testyear>=1998&testyear<=2000&sex=="F"&testyear- birthyear>=15&testyear- birthyear<=17
*sum mom_timeframe

***not need - will be droped by david in next data update:
drop fcatmathnp fcatreadingnp 

***imputing scores from data
foreach var in math reading {
	replace fcat_sss_`var'=normal(fcat_sss_`var')
	gen `var'np_predicted=.
	gen `var'npi=`var'np
	gen `var'np_imputed=0
		label variable `var'np_imputed "Nat'l pct imputed from FCAT"
	gen fcat_sss_`var'2=fcat_sss_`var'*fcat_sss_`var' 
	gen fcat_sss_`var'3=fcat_sss_`var'*fcat_sss_`var' *fcat_sss_`var'
	forv g=3/10 {
		disp "grade "`g'
		reg `var'np fcat_sss_`var' fcat_sss_`var'2 fcat_sss_`var'3 	if grade==`g'
		predict `var'_temp 											if grade==`g'
		replace `var'np_predicted=`var'_temp 						if grade==`g'
		replace `var'np_imputed=1 									if `var'np==.&grade==`g'&`var'np_predicted!=.
		replace `var'npi=`var'np_predicted 							if `var'np==.&grade==`g'
		replace `var'npi=99											if `var'npi>99&`var'npi!=.
		replace `var'npi=1											if `var'npi<1 &`var'npi!=.
		drop `var'_temp
		}
	gen `var'np_10=`var'np if grade==10
	egen temp=mean(`var'np_10), by(scrambled)
	replace `var'np_10=temp	
	gen `var'npi_10=`var'npi if grade==10
	egen tempi=mean(`var'npi_10), by(scrambled)
	replace `var'npi_10=tempi	
	drop fcat_sss_`var'2 fcat_sss_`var'3 temp tempi
	}
	
***renaming for parallel
rename (readingnp readingnpi readingnp_10 readingnpi_10) (readnp readnpi readnp_10 readnpi_10)
label variable mathnp "Math nat'l percentile"
label variable readnp "Reading nat'l percentile"
label var mathnpi "Math nat'l percentile"
label var readnpi "Reading nat'l percentile"

***creating panel
	rename (scrambled scrambled_family ) (id famid)
	sort id
	egen panel = group( id )
	sort panel testyear
	egen famid_alt = group( famid )
**dropping duplicates
	sort id testyear
    quietly by id testyear:  gen dup = cond(_N==1,0,_n)
	tab dup
	* when there are dups (N=92), keep the higher math score
		egen max_math=max(mathnpi), by(id testyear)
		drop if mathnp<max_math&dup>0|mathnpi==.&max_math!=.
		drop dup
		sort id testyear
		quietly by id testyear:  gen dup = cond(_N==1,0,_n)
		tab dup
	* when there are still dups (N=63), keep the higher reading score
		egen max_read=max(readnpi), by(id testyear)
		drop if readnpi<max_read&dup>0|readnpi==.&max_read!=.
		drop dup
		sort id testyear
		quietly by id testyear:  gen dup = cond(_N==1,0,_n)
		tab dup
	* when there are still dups (N=62), they totally match - just keep the first
		drop if dup>1
		drop dup max_read max_math
	
tsset panel testyear

***creating repeat grade variables
gen repeat=0
replace repeat=100 if grade==L.grade
label variable repeat "Repeated grade this year"

gen repeat_later=0
forv i=1/15 {
	replace repeat_later=100 if F`i'.repeat==100
	}
	label variable repeat_later "Repeats in later grade"
	replace repeat_later=. if testyear==2005

gen repeat_before=0
forv i=1/15 {
	replace repeat_before=100 if L`i'.repeat==100
	}
	label variable repeat_before "Repeated in prior grade"

***dropping those without a test score in either year
*drop if readnpi==.&mathnpi==.
tab testyear grade

***reformatting data
**sex
gen female=0
replace female=1 if sex=="F"
label var female "Sister"

gen male=0
replace male=1 if sex=="M"
label var male "Brother"

egen mean_sex=mean(female), by(id)
tab mean_sex
drop mean_sex

**race
rename race r
replace r="Asian" if r=="A"
replace r="Black" if r=="B"
replace r="Hispanic" if r=="H"
replace r="White" if r=="W"
replace r="Other" if r=="I"|r=="M"|r=="O"|r=="P"|r=="U"|r=="X"|r==""
encode r, generate(race)
drop r
tab race

label variable race "Race (1=Asian 2=Black 3=Hisp 4=Other 5=White)"

// replace race with race from first observed(there are some changes)
g race_missing = race == .
sort id race_missing testyear
by id race_missing: g race_new = race if _n == 1 & race_missing == 0 // first nonmissing race 
bys id: egen race_new2 = max(race_new) // it is in fact the only nomissing race_new variable

replace race = race_new2
drop race_new*

*individual indicators
gen black=0
replace black=1 if race==2
gen hispanic=0
replace hispanic=1 if race==3
label variable black "Black"
label variable hispanic "Hispanic"

**lep
rename lep lep_detailed
gen lep=0
replace lep=1 if lep_detailed=="LN"|lep_detailed=="LY"
tab lep
label variable lep "LEP"

**frl
gen frl=1
replace frl=0 if lunch=="none"
label variable frl "FRL"
tab grade, sum(frl)

*mean frl
egen frl_mean=mean(frl), by(id)

// replace frl with frl from first observed(there are some changes)
g frl_missing = frl == .
sort id frl_missing testyear
by id frl_missing: g frl_new = frl if _n == 1 & frl_missing == 0 // first nonmissing frl 
bys id: egen frl_new2 = max(frl_new) // it is in fact the only nomissing frl_new variable

replace frl = frl_new2
drop frl_new*

*disab
gen disab=0
replace disab=1 if primex==""|primex=="Z"|primex=="L"
label variable disab "Exceptional Child"

***dropping unneeded data
drop lep_detailed lunch primex 

**Juvenile Justice
gen jjc=0
replace jjc=100 if firstjuvenile>testyear&firstjuvenile!=.
label variable jjc "Juvenile justice encounter in future year"
replace jjc=. if testyear>=2004

gen jjc_ever=0
replace jjc_ever=100 if firstjuvenile!=.
label variable jjc_ever "Ever juvenile justice"

gen jjc_before=0
replace jjc_before=100 if firstjuvenile<testyear&firstjuvenile!=.
label variable jjc_before "Juvenile justice encounter in prior year"

***Dropout
gen dropout=0
replace dropout=100 if dropout_year>testyear&dropout_year!=.
label variable dropout "Dropped out in future year"
replace dropout =. if testyear>=2004

gen dropout_ever=0
replace dropout_ever=100 if dropout_year!=.
label variable dropout_ever "Ever drops out"

gen dropout_before=0
replace dropout_before=100 if dropout_year<testyear&dropout_year!=.
label variable dropout_before "Dropped out in prior year"
replace dropout_before =. if testyear>=2004

***creating indicators for birth
gen sib_birth=0
replace sib_birth=1 if school_year_birth_parent!=first_school_year_birth_parent & first_school_year_birth_parent<=testyear
label variable sib_birth "Sister had child"

gen birth=0
replace birth=1 if first_school_year_birth_parent<=testyear
label variable birth "Family had child"

gen birth2=0
replace birth2=1 if first_school_year_parent<=testyear
label variable birth2 "Family had child, parent prog then birth"
gen birth3=0
replace birth3=1 if first_school_year_birth<=testyear
label variable birth3 "Family had child, birth only"
gen birth4=0
replace birth4=1 if first_school_year_parentprogram<=testyear
label variable birth4 "Family had child, parent prog only"

***creating years since sibling birth
gen years_since_birth=0
replace years_since_birth=testyear-first_school_year_birth_parent if testyear-first_school_year_birth_parent>=0
label variable years_since_birth "Age of child"

gen years_rel_birth=0
replace years_rel_birth=testyear-first_school_year_birth_parent
label variable years_rel_birth "Years relative to child birth"
*alt mom defs
gen years_rel_birth2=0
replace years_rel_birth2=testyear-first_school_year_parent
label variable years_rel_birth2 "Years relative to child birth"
gen years_rel_birth3=0
replace years_rel_birth3=testyear-first_school_year_birth
label variable years_rel_birth3 "Years relative to child birth"
gen years_rel_birth4=0
replace years_rel_birth4=testyear-first_school_year_parentprogram
label variable years_rel_birth4 "Years relative to child birth"
 
***replacing those missing year-1 but having year-2 so they can be matched later
sort panel testyear
gen expand=0
replace expand=1 if years_rel_birth==-2&F.testyear==.
expand 2 if expand==1, gen(expanded)
	label variable expanded "Expanded to include year -1"

foreach var of varlist grade testyear years_since_birth years_rel_birth years_rel_birth2 years_rel_birth3 years_rel_birth4 {
	replace 	`var'=`var'+1 if expanded==1&`var'!=.
	}
	
foreach var of varlist fcat_sss_math fcat_sss_reading readnp mathnp mathnp_predicted mathnpi mathnp_imputed readingnp_predicted readnpi readingnp_imputed {
	replace `var'=. if expanded==1
	}
 
***populations
g all = 1
g mom = 0
replace mom = 1 if school_year_birth_parent==first_school_year_birth_parent&first_school_year_birth_parent!=.
g sib = 0
replace sib = 1 if school_year_birth_parent!=first_school_year_birth_parent&first_school_year_birth_parent!=.
*alternative methods:
g mom2 = 0
replace mom2 = 1 if school_year_parent==first_school_year_parent&first_school_year_parent!=.
g sib2 = 0
replace sib2 = 1 if school_year_parent!=first_school_year_parent&first_school_year_parent!=.
g mom3 = 0
replace mom3 = 1 if school_year_birth==first_school_year_birth&first_school_year_birth!=.
g sib3 = 0
replace sib3 = 1 if school_year_birth!=first_school_year_birth&first_school_year_birth!=.
g mom4 = 0
replace mom4 = 1 if school_year_parentprogram==first_school_year_parentprogram&first_school_year_parentprogram!=.
g sib4 = 0
replace sib4 = 1 if school_year_parentprogram!=first_school_year_parentprogram&first_school_year_parentprogram!=.

label variable all "All"
label variable mom "Teen mothers"
label variable sib "Sibling of teen mother"

label variable mom2 "Teen mothers, parent prog then birth"
label variable sib2 "Sibling of teen mother, parent prog then birth"
label variable mom3 "Teen mothers, birth only"
label variable sib3 "Sibling of teen mother, birth only"
label variable mom4 "Teen mothers, parent prog only"
label variable sib4 "Sibling of teen mother, parent prog only"

***interactions
gen sib_fem=sib_birth*female
label variable sib_fem "Female X Birth"
gen sib_frl=sib_birth*frl
label variable sib_frl "FRL X Birth"
gen sib_black=sib_birth*black
label variable sib_black "Black X Birth"
gen sib_hisp=sib_birth*hisp
label variable sib_hisp "Hispanic X Birth"

***age at first birth in the family
g age=testyear - birthyear 
g age_cont=testyear - birthyear + (birthmonth-1)/12 + (birthday-1)/12/31
	bys age: sum age_cont
g age_at_birth= first_school_year_birth_parent - birthyear
replace age_at_birth=0 if mom+sib==0
	label variable age_at_birth "Age at child's birth"
g age_at_birth_cont= first_school_year_birth_parent - birthyear + (birthmonth-1)/12 + (birthday-1)/12/31
replace age_at_birth_cont=0 if mom+sib==0
	label variable age_at_birth_cont "Age at child's birth"
	
tab years_rel_birth if abs(years_rel_birth)<6, g(yr)
	rename yr1 yrm5
	rename yr2 yrm4
	rename yr3 yrm3
	rename yr4 yrm2
	rename yr5 yrm1
	rename yr6 yr0
	rename yr7 yr1
	rename yr8 yr2
	rename yr9 yr3
	rename yr10 yr4
	rename yr11 yr5
	gen yrm0=yr0

	label variable  yrm5  "5 years before birth"
	label variable  yrm4  "4 years before birth"
	label variable  yrm3  "3 years before birth"
	label variable  yrm2  "2 years before birth"
	label variable  yrm1  "1 years before birth"
	label variable  yrm0  "Year of birth"
	label variable  yr0  "Year of birth"
	label variable  yr1  "1 years after birth"
	label variable  yr2  "2 years after birth"
	label variable  yr3  "3 years after birth"
	label variable  yr4  "4 years after birth"
	label variable  yr5  "5 years after birth"
	
***age at first birth in the familyS
foreach var of varlist yrm5 yrm4 yrm3 yrm2 yrm1 yrm0 yr0 yr1 yr2 yr3 yr4 yr5 {
	gen `var'_f =`var'*female
	gen `var'_b =`var'*black
	gen `var'_p =`var'*frl
	gen `var'_fb=`var'*female*black
	}

	label variable  yrm5_f  "5 years before birth, female"
	label variable  yrm4_f  "4 years before birth, female"
	label variable  yrm3_f  "3 years before birth, female"
	label variable  yrm2_f  "2 years before birth, female"
	label variable  yrm1_f  "1 years before birth, female"
	label variable  yr0_f  "0 year of birth, female"
	label variable  yr1_f  "1 years after birth, female"
	label variable  yr2_f  "2 years after birth, female"
	label variable  yr3_f  "3 years after birth, female"
	label variable  yr4_f  "4 years after birth, female"
	label variable  yr5_f  "5 years after birth, female"
	
	label variable  yrm5_b  "5 years before birth, Black"
	label variable  yrm4_b  "4 years before birth, Black"
	label variable  yrm3_b  "3 years before birth, Black"
	label variable  yrm2_b  "2 years before birth, Black"
	label variable  yrm1_b  "1 years before birth, Black"
	label variable  yr0_b  "0 year of birth, Black"
	label variable  yr1_b  "1 years after birth, Black"
	label variable  yr2_b  "2 years after birth, Black"
	label variable  yr3_b  "3 years after birth, Black"
	label variable  yr4_b  "4 years after birth, Black"
	label variable  yr5_b  "5 years after birth, Black"

	label variable  yrm5_fb  "5 years before birth, female*Black"
	label variable  yrm4_fb  "4 years before birth, female*Black"
	label variable  yrm3_fb  "3 years before birth, female*Black"
	label variable  yrm2_fb  "2 years before birth, female*Black"
	label variable  yrm1_fb  "1 years before birth, female*Black"
	label variable  yr0_fb  "0 year of birth, female*Black"
	label variable  yr1_fb  "1 years after birth, female*Black"
	label variable  yr2_fb  "2 years after birth, female*Black"
	label variable  yr3_fb  "3 years after birth, female*Black"
	label variable  yr4_fb  "4 years after birth, female*Black"
	label variable  yr5_fb  "5 years after birth, female*Black"

	label variable  yrm5_p  "5 years before birth, FRL"
	label variable  yrm4_p  "4 years before birth, FRL"
	label variable  yrm3_p  "3 years before birth, FRL"
	label variable  yrm2_p  "2 years before birth, FRL"
	label variable  yrm1_p  "1 years before birth, FRL"
	label variable  yr0_p  "0 year of birth, FRL"
	label variable  yr1_p  "1 years after birth, FRL"
	label variable  yr2_p  "2 years after birth, FRL"
	label variable  yr3_p  "3 years after birth, FRL"
	label variable  yr4_p  "4 years after birth, FRL"
	label variable  yr5_p  "5 years after birth, FRL"
	
	*making zero's for non-sibling families
	foreach var of varlist yrm5 yrm4 yrm3 yrm2 yrm1 yrm0 yr0 yr1 yr2 yr3 yr4 yr5 yrm5_f yrm5_b yrm5_p yrm5_fb yrm4_f yrm4_b yrm4_p yrm4_fb yrm3_f yrm3_b yrm3_p yrm3_fb yrm2_f yrm2_b yrm2_p yrm2_fb yrm1_f yrm1_b yrm1_p yrm1_fb yr0_f yr0_b yr0_p yr0_fb yr1_f yr1_b yr1_p yr1_fb yr2_f yr2_b yr2_p yr2_fb yr3_f yr3_b yr3_p yr3_fb yr4_f yr4_b yr4_p yr4_fb yr5_f yr5_b yr5_p yr5_fb {
		replace `var'=0 if sib+mom==0
		}
		
***age proximity
	egen 	temp_min=min(age_at_birth) if mom==1, by(famid)
	egen 	temp_max=max(age_at_birth) if mom==1, by(famid)
		egen 	age_at_birth_mom_min=mean(temp_min), by(famid)
		egen 	age_at_birth_mom_max=mean(temp_max), by(famid)
	gen 	closest_sib_age_dif=age_at_birth-age_at_birth_mom_min if sib==1
	replace	closest_sib_age_dif=age_at_birth-age_at_birth_mom_max if sib==1&abs(age_at_birth-age_at_birth_mom_min )>abs(age_at_birth-age_at_birth_mom_max)
		label variable closest_sib_age_dif "Minimum difference from first sibling to give birth"
		drop temp_min temp_max

	preserve
		collapse  birthdate, by(panel famid)
		sort famid birthdate
		gen dist_to_older_sib = (birthdate-birthdate[_n+1])/365 if famid == famid[_n+1]
		tempfile temp
		save `temp'
	restore
		merge m:1 panel using `temp' 
		drop _merge
		
	gen close=0
	replace close=1 if closest_sib_age_dif>-4&closest_sib_age_dif<=0
	replace close=1 if dist_to_older_sib>-4&dist_to_older_sib<=0&sib+mom==0
		label variable close "Sibling 3 years or less from mom age"
		*manually checked families with 3+ teen moms - all 3 such families only had 1 birth in the first year (i.e., no problem with the above formula)
		tab famid if numteenmoms>2
	gen closesis=close*female
		label variable close "Sister 1 year or less from mom age"

***Sequence number
	sort panel age
	bys panel: gen seq=_n

***Mean score outcome
egen pct=		rowmean (mathnp readnp)
egen pcti=		rowmean(mathnpi readnpi)
egen pct_10=	rowmean (mathnp_10 readnp_10)
egen pcti_10=	rowmean(mathnpi_10 readnpi_10)

***Family scores
foreach var of varlist pcti {
	egen sum_`var' = sum(`var'), by(famid testyear)
	egen count_`var' = count(`var'), by(famid testyear)
	gen `var'_fam = (sum_`var' - `var') / (count_`var' - 1)
	drop sum_`var' count_`var'
	}

***first observed score
	sort id testyear
	by id: gen count=_n
	tab count
foreach var of varlist pct mathnp readnp pcti mathnpi readnpi grid pcti_fam {
	gen `var'_first=`var'
	forv i = 1/16 {
		replace `var'_first=`var'[_n-`i']       if panel==panel[_n-`i']&`var'[_n-`i']!=.
		replace `var'_first=`var'_first[_n+`i'] if panel==panel[_n+`i']&`var'_first[_n+`i']!=.&`var'_first==.
		}
	}
	drop count

***Previous Scores
sort panel testyear
foreach var of varlist pct mathnp readnp pcti mathnpi readnpi pcti_fam {
	forv i=0/9 {
		gen missing_`var'L`i'=0
		replace missing_`var'L`i'=1 if L`i'.`var'==.
		gen `var'L`i'=L`i'.`var'
		forv j=`i'/5 {
			replace `var'L`i'=L`j'.`var'	      if `var'L`i'==.
			}
		replace `var'L`i'=`var'_first if `var'L`i'==.&seq!=1
		forv j=`i'(-1)1 {
			replace `var'L`i'=L`j'.`var'       	  if `var'L`i'==.
			}	
		gen missing_`var'F`i'=0
		replace missing_`var'F`i'=1 if F`i'.`var'==.
		gen `var'F`i'=F`i'.`var'
		*replace `var'F`i'=`var'[_n+1] if seq==1&panel==panel[_n+1] & `var'F`i'==.
		forv j=`i'/5 {
			replace `var'F`i'=F`j'.`var'       	  if `var'F`i'==.
			}
		forv j=`i'(-1)1 {
			replace `var'F`i'=F`j'.`var'          if `var'F`i'==.
			}
		}
	sum `var'*
	}

	
***summary by school
foreach var of varlist frl black hisp mathnp readnp mathnp_first readnp_first pct_first mathnpi readnpi mathnpi_first readnpi_first pcti_first {
	egen school_`var'=mean(`var'), by(schnum)
	}
	label variable school_frl "School avg. FRL"
	label variable school_black "School avg. Black"
	label variable school_hisp "School avg. Hispanic"
	label variable school_pct_first "School avg. first score"
	label variable school_mathnp_first "School avg. first math"
	label variable school_readnp_first "School avg. first reading"
	label variable school_pcti_first "School avg. first score"
	label variable school_mathnpi_first "School avg. first math"
	label variable school_readnpi_first "School avg. first reading"	
*first school score
foreach var of varlist school_frl school_black school_hisp school_pct_first school_mathnp_first school_readnp_first school_pcti_first school_mathnpi_first school_readnpi_first {
	gen first_`var'=`var'
	forv i = 1/11 {
		replace first_`var'=`var'[_n-`i']       if panel==panel[_n-`i']&`var'[_n-`i']!=.
		replace first_`var'=first_`var'[_n+`i'] if panel==panel[_n+`i']&first_`var'[_n+`i']!=.&first_`var'==.
		}
	}	
	label variable first_school_frl "First-observed School avg. FRL"
	label variable first_school_black "First-observed School avg. Black"
	label variable first_school_hisp "First-observed School avg. Hispanic"
	label variable first_school_pct_first "First-observed School avg. first score"
	label variable first_school_mathnp_first "First-observed School avg. first math"
	label variable first_school_readnp_first "First-observed School avg. first reading"
	label variable first_school_pcti_first "First-observed School avg. first score"
	label variable first_school_mathnpi_first "First-observed School avg. first math"
	label variable first_school_readnpi_first "First-observed School avg. first reading"	
	
***Previous School
sort panel testyear
foreach var of varlist school_frl school_black school_pcti_first {
	forv i=0/5 {
		gen missing_`var'L`i'=0
		replace missing_`var'L`i'=1 if L`i'.`var'==.
		gen `var'L`i'=L`i'.`var'
		forv j=`i'/5 {
			replace `var'L`i'=L`j'.`var'	      if `var'L`i'==.
			}
		}
	sum `var'*
	}
	
***mother's age at birth	
gen Age15Less=0
	replace Age15Less=1 if age_at_birth_mom_max<16
	label variable Age15Less "Mother had child at age 15 or younger"
gen Age16=0
	replace Age16=1 if age_at_birth_mom_max==16
	label variable Age16 "Mother had child at age 16"
gen Age17=0
	replace Age17=1 if age_at_birth_mom_max==17
	label variable Age17 "Mother had child at age 17"
gen Age18Plus=0
	replace Age18Plus=1 if age_at_birth_mom_max>17
	label variable Age18Plus "Mother had child at age 18 or older"	
***age differences	
	gen age_dif=age_at_birth-age_at_birth_mom_max
	hist age_dif if mom==0, width(1)
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\age_difference.png, replace

	gen age_dif_older=0
		replace age_dif_older=1 if age_dif>=0&age_dif!=.&mom==0
			egen temp=mean(age_dif_older), by(famid)
			replace age_dif_older=1 if mom==1&temp>0&temp!=.
			drop temp
			label variable age_dif_older "Sibling Older than Teen Mom"
	gen age_dif_1younger=0
		replace age_dif_1younger=1 if age_dif>=-1&age_dif<0&age_dif!=.
			egen temp=mean(age_dif_1younger), by(famid)
			replace age_dif_1younger=1 if mom==1&temp>0&temp!=.
			drop temp
			label variable age_dif_1younger "Sibling 1 Year Younger than Teen Mom"

	gen age_dif_2younger=0
		replace age_dif_2younger=1 if age_dif>=-2&age_dif<-1&age_dif!=.
			egen temp=mean(age_dif_2younger), by(famid)
			replace age_dif_2younger=1 if mom==1&temp>0&temp!=.
			drop temp
			label variable age_dif_2younger "Sibling 2 Years Younger than Teen Mom"
	gen age_dif_12younger=age_dif_1younger+age_dif_2younger
			replace age_dif_12younger=1 if age_dif_12younger==2
			label variable age_dif_12younger "Sibling 1-2 Years Younger than Teen Mom"

	gen age_dif_3pyounger=0
		replace age_dif_3pyounger=1 if age_dif<-2&age_dif!=.
			egen temp=mean(age_dif_3pyounger), by(famid)
			replace age_dif_3pyounger=1 if mom==1&temp>0&temp!=.
			drop temp
			label variable age_dif_3pyounger "Sibling 3+ Years Younger than Teen Mom"	
	gen rel_age=.
		replace rel_age=0 if age_dif_3pyounger==1
		replace rel_age=1 if age_dif_2younger==1
		replace rel_age=2 if age_dif_1younger==1
		replace rel_age=3 if age_dif_older==1
		label variable rel_age "Age relative to teen mother"
	gen oldest=0
		egen oldest_bd=min(birthdate), by(famid)
		replace oldest=1 if birthdate==oldest_bd
		drop oldest_bd
		label variable oldest "Oldest child in family in dataset"
	gen youngest=0
		egen youngest_bd=max(birthdate), by(famid)
		replace youngest=1 if birthdate==youngest_bd
		drop youngest_bd
		label variable youngest "Youngest child in family in dataset"		
***maximum age in school
	egen max_age=max(age), by(id)
	egen temp=max(age) if mom==1, by(id)
	egen max_age_mom=max(temp), by(famid)
		drop temp
		gen mompastreq=0
		replace mompastreq=1 if max_age_mom>15
			label variable mompastreq "Mother has more than compulsary education"
		
**two sibling family
	gen twosib=0
	replace twosib=1 if famcount==2
		label variable twosib "Two siblings in family"

***On/Off Birth
gen birth_mom=birth*mom
	label variable birth_mom "Effect of birth - mother"
gen birth_sib=birth*sib		
	label variable birth_sib "Effect of birth - sibling"

		
gen mom_on=0
replace mom_on=1 if years_rel_birth>=0& years_rel_birth!=.
label var mom_on "Post-birth"	

gen sib_on=0
replace sib_on=1 if years_rel_birth>=0& years_rel_birth!=.
label var sib_on "Post-birth"	

gen years_rel_birth_on=0
replace years_rel_birth_on=years_rel_birth+1 if years_rel_birth>=0
label variable years_rel_birth_on "Years relative to child birth X Post-birth
	
forv i=2/4 {
	foreach var of varlist mom sib {
		gen `var'`i'_on=birth`i'*`var'
		}
	}
	
***prwora - passed August 1996, became effective July 1, 1997 - Wikipedia: https://en.wikipedia.org/wiki/Personal_Responsibility_and_Work_Opportunity_Act
	gen prwora=0
	replace prwora=1 if first_school_year_birth_parent>1997
	label variable prwora "Post-PRWORA"

	gen Age16_YesPRWORA=0
		replace Age16_YesPRWORA=1 if Age16==1&prwora==1
		label variable Age16_YesPRWORA "Mother at 16 Post-PRWORA"
	gen Age16_NoPRWORA=0
		replace Age16_NoPRWORA=1 if Age16==1&prwora==0
		label variable Age16_NoPRWORA  "Mother at 16 Pre-PRWORA"
		tab first_school_year_parent 	
	
***Making groups
gen group=.
replace group=1 if sib==1
replace group=2 if mom==1
replace group=3 if mom+sib==0
tab group, m
	label define group 1 "Sibling" 2 "Teen Mother" 3 "Other Families"
	label values group group
***examining panel options
	egen years_rel_birth_min=min(years_rel_birth), by(id)
		tab years_rel_birth_min
	egen years_rel_birth_max=max(years_rel_birth), by(id)
		tab years_rel_birth_max
	egen count=count(years_rel_birth), by(id)
	egen max_testyear=max(testyear), by(id)
	egen min_testyear=min(testyear), by(id)
	gen  missing=count/(max_testyear-min_testyear+1)
		label variable missing "Percent of missing observations"
		drop max_testyear min_testyear
	gen temp=1 if years_rel_birth==0
		egen hasyr0=mean(temp), by(id)
		drop temp
	preserve 
		collapse count black female missing years_rel_birth_min years_rel_birth_max mom, by(id)
				tab years_rel_birth_min years_rel_birth_max if mom==0
		tab years_rel_birth_min years_rel_birth_max if mom==0&years_rel_birth_min<=-3&years_rel_birth_max>=0
		tab years_rel_birth_min years_rel_birth_max if mom==0&years_rel_birth_min<=-3&years_rel_birth_max>=0, sum(count) nost nof
		tab years_rel_birth_min years_rel_birth_max if mom==0&years_rel_birth_min<=-3&years_rel_birth_max>=0, sum(missing) nost nof
	restore
	
	forv i = 1/5 {
	gen fullpanel_`i' = 0
		gen temp=1 if years_rel_birth==-`i'
			egen hasyr`i'=mean(temp), by(id)
		replace fullpanel_`i' = 1 if hasyr0==1&hasyr`i'==1
		label var fullpanel_`i' "Has Year -`i'and Year 0"
			drop temp 
	}

	egen panelreq = rowmax(fullpanel_2 fullpanel_3 fullpanel_4 fullpanel_5)
*	forv i = 2/2 {
*	gen panelreq = 0
*		replace panelreq = 1 if years_rel_birth_min<=-`i'&hasyr0==1
*		label var panelreq "Has at least `i' years before birth, through birth"
*	}	

**kernel densities for population
	*by age for test takers we observe at t=0
	twoway 	(kdensity age_cont if mom==0&sib==1& years_rel_birth==0		&mathnpi!=., 	   lcolor(black) lwidth(medthick)) ///
			(kdensity age_cont if mom==1& years_rel_birth==0			&mathnpi!=.,      lcolor(gray)  lwidth(medthick) lpattern(dash)), 	///					
			legend(order(1 "Siblings" 2 "Mothers")) graphregion(color(white)) xtitle(Age at Birth) ytitle(Density)
		graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\age_at_birth.png, replace
	*by age for test takers we have in data
	twoway 	(kdensity age_cont if mom==0&sib==1		&mathnpi!=., 	   lcolor(black) lwidth(medthick)) ///
			(kdensity age_cont if mom==1			&mathnpi!=.,      lcolor(gray)  lwidth(medthick) lpattern(dash)), 	///					
			legend(order(1 "Siblings" 2 "Mothers")) graphregion(color(white)) xtitle(Testing Ages Available) ytitle(Density)
		graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\age_at_test.png, replace
	*by grade for test takers we have in data
	twoway 	(hist grade if mom==1					& mathnpi!=., width(1)   lcolor(gray)  lwidth(medthick) color(gray)) ///
			(hist grade if mom==0&sib==1			& mathnpi!=., width(1)   lcolor(black)  lwidth(medthick) color(none)), 	///					
			legend(order(2 "Siblings" 1 "Mothers")) graphregion(color(white)) xtitle(Testing Grades Available) ytitle(Density)
		graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\grade_at_test.png, replace
	
**kdensity of frl distribution
	twoway 	(kdensity frl_mean if mom==0&sib==1		, 	   lcolor(black) lwidth(medthick)) ///
			(kdensity frl_mean if mom==1			,      lcolor(gray)  lwidth(medthick) lpattern(dash)) 	///					
			(kdensity frl_mean if mom==0&sib==0		,      lcolor(gray)  lwidth(medthick) lpattern(dot)), 	///					
			legend(order(1 "Siblings" 2 "Mothers" 3 "Other Families")) graphregion(color(white)) xtitle(Continuous FRL Variable) ytitle(Density)
		graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\frl_continuous.png, replace
	graph drop _all

***Year ranges
	egen max=max(testyear), by(id)
	egen min=min(testyear), by(id)
	gen range=max-min
	drop max min
	label variable range "Range of years"	

	graph drop _all
	
***family composition
preserve
	collapse female sib mom age_at_birth, by(id famid)
	keep if sib==1
	egen has_sib=sum(sib), by(famid)
	gen sis=sib*female
	egen has_sis=sum(sis), by(famid)
	gen bro=0
		replace bro=1 if sib==1&female==0
	egen has_bro=sum(bro), by(famid)
	keep famid has_sib has_sis has_bro
	collapse has_sib has_sis has_bro, by(famid)
	tab has_sib has_sis
	label variable has_sib "Has other younger sibling"
	label variable has_sis "Has other younger sister"
	label variable has_bro "Has other younger brother"
	tempfile temp
	save `temp', replace
restore
	merge m:1 famid using `temp'
	gen mom_withsib=0
	replace mom_withsib=1 if mom==1&has_sib>0&has_sib!=.
	label variable mom_withsib "Mom has younger sibling"
	gen mom_withsis=0
	replace mom_withsis=1 if mom==1&has_sis>0&has_sis!=.
	label variable mom_withsis "Mom has younger sister"
	gen mom_withbro=0
	replace mom_withbro=1 if mom==1&has_bro>0&has_bro!=.
	label variable mom_withbro "Mom has younger brother"	
	replace has_sib=has_sib-1		if sib==1
	replace has_sis=has_sis-female 	if sib==1
	replace has_bro=has_bro-1+female 	if sib==1
	
	tab has_sis has_bro

	replace has_sib=0 if has_sib==.
	replace has_sis=0 if has_sis==.
	replace has_bro=0 if has_bro==.

	replace has_sib=1 if has_sib!=.&has_sib>1
	replace has_sis=1 if has_sis!=.&has_sis>1
	replace has_bro=1 if has_bro!=.&has_bro>1
	
***dropout replacement
	preserve
	keep if testyear==dropout_year
	expand 2, gen(dropout_replacement)
	tab dropout_replacement
	drop if dropout_replacement==0
	replace age=age+1 if dropout_replacement==1
	replace testyear=testyear+1 if dropout_replacement==1
	replace years_rel_birth=years_rel_birth+1 if dropout_replacement==1
	gen		pcti_replacement=1 if dropout_replacement==1
	keep id panel testyear grid dropout_replacement pcti_replacement age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first
	tempfile replacement
	save `replacement'
	restore
	append using `replacement'
	replace pcti_replacement=pcti if dropout_replacement==.
	tab dropout_replacement, m
	
	duplicates tag id testyear, gen(tag)
	tab tag
	sort tag id	
	
	drop if dropout_replacement==1&tag==1
	drop tag
	
***creating z-scores	
generate zscore = invnorm(pcti/100)	
generate zscore_10 = invnorm(pcti_10/100)	
	label var zscore_10 "Z-score in 10th grade"
generate zscore_math = invnorm(mathnpi/100)	
	label var zscore_math "Math Z-score"
generate zscore_read = invnorm(readnpi/100)	
	label var zscore_read "Reading Z-score"
generate zscore_replacement = invnorm(pcti_replacement/100)	
	label var zscore_replacement "Z-score with minimum value replacement"
generate zscore_noreplacement = invnorm(pct/100)	
	label var zscore_noreplacement "Z-score without imputation"
gen sibormom=sib+mom

**10th grade
sort panel testyear	
foreach var of varlist pcti_replacement zscore_math zscore_read zscore_replacement zscore_noreplacement {
	gen `var'_10=`var' if grade==10
	egen temp=mean(`var'_10), by(id)
	replace `var'_10=temp
	drop temp
	}

***NSC data
preserve
use "C:\Users\jah970\Documents\NSC\scrambled_nsc_data.dta", clear
*ever college
	gen col_ever			=0
	replace col_ever		=1 if Record_Found_Y_N=="Y"
*ever 4-year
	gen col_ever_4yr		=0 
	replace col_ever_4yr	=1 if A2_year___4_year=="4"
*college degree
	gen col_degree			=0
	replace col_degree		=1 if Graduated_=="Y"
*college degree, bch or higher
	gen col_degree_4yr			=0
	replace col_degree_4yr=1 if strpos(Degree_Title,"BACHELOR")
	replace col_degree_4yr=1 if strpos(Degree_Title,"BS ")	
	replace col_degree_4yr=1 if strpos(Degree_Title,"BS/")	
	replace col_degree_4yr=1 if strpos(Degree_Title,"BS-")	
	replace col_degree_4yr=1 if Degree_Title=="BS"
	replace col_degree_4yr=1 if strpos(Degree_Title,"BA ")	
	replace col_degree_4yr=1 if strpos(Degree_Title,"AB IN ")
	replace col_degree_4yr=1 if Degree_Title=="AB"
	replace col_degree_4yr=1 if Degree_Title=="BSACC"
	replace col_degree_4yr=1 if Degree_Title=="BSM"
	replace col_degree_4yr=1 if Degree_Title=="BSN"
	replace col_degree_4yr=1 if Degree_Title=="BSW"
	replace col_degree_4yr=1 if strpos(Degree_Title,"BSH")
	replace col_degree_4yr=1 if strpos(Degree_Title,"BBA")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BSIT")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BSC")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BBA")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BSB")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B A")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B B A")	
	replace col_degree_4yr=1 if strpos(Degree_Title,"B.S.")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B S")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BS ")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BS*")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B.S.")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B. S.")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B.A.")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B.L.S.")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B.M.")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"B.B.A.")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BFA")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BA")
	replace col_degree_4yr=1 if strpos(Degree_Title,"BM")		
	replace col_degree_4yr=1 if strpos(Degree_Title,"BACH")		
	
	replace col_degree_4yr=1 if strpos(Degree_Title,"MASTER ")
	replace col_degree_4yr=1 if strpos(Degree_Title,"ASTER OF")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MSTR ")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MAST ")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MASTER")
	replace col_degree_4yr=1 if strpos(Degree_Title,"M.S.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MS ")
	replace col_degree_4yr=1 if strpos(Degree_Title,"M.A.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MA ")
	replace col_degree_4yr=1 if strpos(Degree_Title,"M A ")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MA-")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MBA")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MHA")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MHS")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MPP")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MPH")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MPA")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MSP")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MSN")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MSA")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MS-")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MAED")
	replace col_degree_4yr=1 if strpos(Degree_Title,"ED.M.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"M. S.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"M. A.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"M S ")
	replace col_degree_4yr=1 if strpos(Degree_Title,"ED.M.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MS/")
	replace col_degree_4yr=1 if strpos(Degree_Title,"PHYSICIAN ASSISTANT")
	replace col_degree_4yr=1 if Degree_Title=="M. ED"
	replace col_degree_4yr=1 if Degree_Title=="M P H"
	replace col_degree_4yr=1 if Degree_Title=="M.F.A."
	replace col_degree_4yr=1 if Degree_Title=="M.H.A."
	replace col_degree_4yr=1 if Degree_Title=="MACC"
	replace col_degree_4yr=1 if Degree_Title=="MAE"
	replace col_degree_4yr=1 if Degree_Title=="MAT"
	replace col_degree_4yr=1 if Degree_Title=="ME"
	replace col_degree_4yr=1 if Degree_Title=="MED"
	replace col_degree_4yr=1 if Degree_Title=="MRS"
	replace col_degree_4yr=1 if Degree_Title=="MIS"
	replace col_degree_4yr=1 if Degree_Title=="MS"
	replace col_degree_4yr=1 if Degree_Title=="MSED"
	replace col_degree_4yr=1 if Degree_Title=="MSLS"
	replace col_degree_4yr=1 if Degree_Title=="MSW"
	replace col_degree_4yr=1 if Degree_Title=="M P H"
	replace col_degree_4yr=1 if Degree_Title=="M H A"
	replace col_degree_4yr=1 if Degree_Title=="M A"
	replace col_degree_4yr=1 if Degree_Title=="MA"
	replace col_degree_4yr=1 if Degree_Title=="MSA"
	replace col_degree_4yr=1 if Degree_Title=="MSLA"
	replace col_degree_4yr=1 if Degree_Title=="MLA"
	replace col_degree_4yr=1 if Degree_Title=="MFA"
	replace col_degree_4yr=1 if Degree_Title=="MDIV"
	replace col_degree_4yr=1 if Degree_Title=="M OF BUSINESS ADMINISTRATION"

	replace col_degree_4yr=1 if Degree_Title=="MD"
	replace col_degree_4yr=1 if strpos(Degree_Title,"M.D.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"M D")
	replace col_degree_4yr=1 if strpos(Degree_Title,"MD	")
	replace col_degree_4yr=1 if strpos(Degree_Title,"PHD")
	replace col_degree_4yr=1 if strpos(Degree_Title,"PH.D.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"DOCTOR")
	replace col_degree_4yr=1 if strpos(Degree_Title,"DR. OF")
	replace col_degree_4yr=1 if strpos(Degree_Title,"DR OF")
	replace col_degree_4yr=1 if strpos(Degree_Title,"DOC.")
	replace col_degree_4yr=1 if strpos(Degree_Title,"PHARMD")
	replace col_degree_4yr=1 if Degree_Title=="DO"
	replace col_degree_4yr=1 if Degree_Title=="DN"
	replace col_degree_4yr=1 if Degree_Title=="DVM"
	replace col_degree_4yr=1 if Degree_Title=="DPH"
	replace col_degree_4yr=1 if Degree_Title=="DPT"
	replace col_degree_4yr=1 if Degree_Title=="JD"
	replace col_degree_4yr=1 if Degree_Title=="J.D."
	replace col_degree_4yr=1 if Degree_Title=="J D"

	collapse (max) col_ever col_ever_4yr col_degree col_degree_4yr, by(scrambled)
	
*labels
	label variable col_ever "Ever attends college"
	label variable col_ever_4yr "Ever attends 4-year college"
	label variable col_degree "Received degree"
	label variable col_degree_4yr "Received bachelor's degree or higher"

*rename id to merge to main file
	rename scrambled id
*merge to main file	
	save `temp', replace
	restore
	
	drop _merge
	merge m:1 id using `temp'
	drop if _merge==2
	drop _merge

*foreach var of varlist pctL0 pctL1 pctL2 pctL3 pctL4 pctL5 pctiL0 pctiL1 pctiL2 pctiL3 pctiL4 pctiL5 	missing_pctiL0 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 missing_pctiL5		{
*	egen sum_`var' = sum(`var') if age<=17, by(famid testyear)
*	egen count_`var' = count(`var') if age<=17, by(famid testyear)
*	gen `var'_fam = (sum_`var' - `var') / (count_`var' - 1)
*	drop sum_`var' 
*	}
		
save "C:\Users\jah970\Documents\Sibling Spillover\data\d_cleaned data.dta", replace
