******************************
***Florida Sibling Analysis***
***Jenni Heissel**************
***July 25, 2014**************
***Analyzing FL Data**********
******************************
******************************

use "D:\Sibling Spillover\data\d_cleaned data.dta", clear
	set more off
***all years
*preserve
*qui: hist years_rel_birth, start (-15) width(1) graphregion(color(white)) bgcolor(white) freq ///
*	title(Years Relative to Sister's First Birth)
*	graph export "C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\hist_years_since_birth.png", replace
*restore

***Limit population: Only sibings from families with at least one teen mom (age 15-17)
**Siblings may include people from families with 1 sib <16, 1 at least 15
drop if mom==1
drop if  age_at_birth_mom_max!=15&age_at_birth_mom_max!=16&age_at_birth_mom_max!=17&sib==1|age_at_birth_mom_min!=15&age_at_birth_mom_min!=16&age_at_birth_mom_min!=17&sib==1
*keep if age_dif<abs(10)|age_dif==.

gen age2=age*age
gen age3=age*age2
gen age_cont2=age_cont*age_cont
***limit to having at least an observation at t=0 and one before that 
	*egen temp=min(years_rel_birth) if sib+mom!=0, by(id)
	*	tab temp
	*	drop if temp>=0&temp!=.
	*gen temp2=0 if years_rel_birth==0
	*	egen temp3=mean(temp2), by(id)
	*	drop if temp3==.&sib+mom!=0
	*drop temp
	*drop temp temp2 temp3
**and SIBS must have an obs at T=0 and at least 1 at T=-2, -3, -4, or -5
*drop if panelreq==0&sib==1
**Must be OLDER siblings
*keep if age_dif>0&sib==1|mom+sib==0&youngest==0
keep if oldest==1&sib==1|mom+sib==0&youngest==0

*R-squared review
	sort panel testyear
	reg mathnp L5.readnp if grade==8&L5.grade==3
	reg readnp L5.mathnp if grade==8&L5.grade==3
	
***setting random
set seed 123456
gen random=runiform()
sort random

tab age_dif
tab years_rel_birth sib if pct!=.
sum missing_pctiL* if sib==1 & age_dif>0 & age_dif<9
drop if sib==1 & age_at_birth<=18
drop if sib==0 & age<=13
*keep if testyear>=1995
sum missing_pctiL* if sib==1 &years_rel_birth==-5
sum missing_pctiL* if sib==1 &years_rel_birth==-5 & missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<1999

***Creating matched synthetic control group
	eststo clear
*	local if "if mom+sib==0&seq==1|sib==1&seq==1"
*all main analysis to be the same population:
	local if "if mom+sib==0	&age>=14	&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<1999 |sib==1&years_rel_birth==-5&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<1999"
eststo: logit sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first `if'
		estat ic
		*predict phat1 `if'
		*gen     phat2=phat1+grid_first*10 `if'
*limited to minimize AIC
eststo: logit sib i.age famcount oldest  black  first_school_black first_school_pcti_first `if'	
		predict phat3 `if'
		gen     phat4=phat3+grid_first*10 `if'

*T=-2
eststo: logit sib female i.age famcount oldest frl black pctiL1 missing_pctiL1 first_school_frl first_school_black first_school_pcti_first `if'
estat ic
*limited:
eststo: logit sib famcount oldest black first_school_black first_school_pcti_first `if'
		predict phat19 `if'
		gen     phat20=phat19+grid_first*10 `if'		
***longitudinal matching
*other controls 
***Creating matched synthetic control group

*other controls 
eststo: logit sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3  missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first `if'
estat ic
*limited:
eststo: logit sib  famcount oldest black missing_pctiL2 first_school_black first_school_pcti_first `if'
		predict phat6 `if'
		gen     phat7=phat6+grid_first*10 `if'
***With FAM trajectories
local if "if mom+sib==0	&age>=14	&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<1999& missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1 |sib==1&years_rel_birth==-5&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<1999& missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1"

eststo: logit sib female i.age famcount oldest frl black pcti_famL1 pcti_famL2 pcti_famL3  missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 pctiL1 pctiL2 pctiL3  missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first `if'
estat ic
*limited:
eststo: eststo: logit sib i.age famcount oldest black first_school_pcti_first `if'
		predict phat23 `if'
		gen     phat24=phat23+grid_first*10 `if'
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\TA1_logit_oldersib.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("1st OBS" "T=-2" "IND" "IND+FAM") 
	eststo clear

**making group id's for sibs
	preserve
	**make a list of ids for siblings with data in year=0
	keep if sib==1&years_rel_birth==-5
	bys id: gen pop = 1 if _n==1
	replace pop = sum(pop) 
	keep id pop
	collapse pop, by(id)
	tempfile pop
	save `pop', replace
	restore
	merge m:1 id using `pop'
	drop _merge
	egen maxpop = max(pop)
	local end = maxpop[1]
	drop maxpop
	
**making a list of IDs
preserve
	clear
	gen id=""
	gen testyear=.
	gen series=.
	tempfile list
	save `list', replace
restore

	tempfile main
	save `main', replace

	tab pop if pop==`end'

	*forv w = 3/17 {
	foreach w in 6 7 23 24 {
		*forv i = 1/29	{
		forv i = 1/`end'	{
			use `main', clear
			keep if mom+sib==0&phat`w'!=.|sib==1&years_rel_birth==-5&pop==`i'&phat`w'!=.
			egen max_sib=max(sib)
			if max_sib==0 {
				disp "w - i is "`w' `i'
				}
			else {
			forv j = 1/5 {
				psmatch2 sib, pscore(phat`w') neighbor(1) out(testyear) caliper(1)
				preserve
					keep if _weight==1 & sib==0
					gen series=`j'*1000+`i'
					keep id testyear series
					append using `list'
					save `list', replace
				restore
				egen temp=max(_weight), by(id)
				drop if sib==0&temp==1
				drop temp
					}
				disp "w - i is "`w' `i'
				}
			}
			use `list', clear
			collapse (count) series, by(id testyear)
			replace series=series/5
			rename series weight`w'
			gen n=_n
			egen id2=concat(id n)
			drop n
			save `list', replace
				/*
				*sidetrip to make weighted list of times relative to the matchesd year (i.e., years_rel_birth for all)
				preserve
					*make 8 obs per sample
					expand 8
					*make one for each year -5 to +2 relative to year 0 (year of match)
					sort id2 testyear
					by id2 testyear: generate long obs = _n
					rename (testyear weight`w') (testyear_match weight`w'_rel)
					gen years_rel_birth=obs-6-3
					*plus one b/c match occurs year before birth in regular, then 4 more for -5 total in older sibling
					gen  testyear=testyear_match+years_rel_birth+5
					tempfile temp
					save `temp'
					*add siblings, match to test scores by year
					use `main', clear
						keep id testyear years_rel_birth sib phat`w'
						egen keep=max(phat`w'), by(id)
						keep if sib==1&keep!=.
						drop phat`w' keep
						gen weight`w'_rel=1
						append using `temp'
						merge m:1 id testyear using `main'
						replace id2=id if id2==""
						replace sib=0 if sib==.
						drop yr*
						tab years_rel_birth if years_rel_birth>=-8&years_rel_birth<=-1, g(yr)
							rename yr1 yrm8
							rename yr2 yrm7
							rename yr3 yrm6
							rename yr4 yrm5
							rename yr5 yrm4
							rename yr6 yrm3
							rename yr7 yrm2
							rename yr8 yrm1
							
							label variable  yrm8  "8 years before birth"
							label variable  yrm7  "7 years before birth"							
							label variable  yrm6  "6 years before birth"
							label variable  yrm5  "5 years before birth"
							label variable  yrm4  "4 years before birth"
							label variable  yrm3  "3 years before birth"
							label variable  yrm2  "2 years before birth"
							label variable  yrm1  "1 years before birth"

							***added 7/9/17 to redo panel with new id: 
							drop if years_rel_birth==.
							***recreating panel
							drop panel
							sort id2
							egen panel = group( id2 )
							sort panel testyear
							quietly by panel testyear:  gen dup = cond(_N==1,0,_n)
							tab dup
							
							tsset panel testyear
							
					save "D:\Users\jah970\Documents\Sibling Spillover\data\b_years_rel_birth_`w'_oldersibs", replace	
				restore
					*/
			merge 1:m id testyear using `main'
				display "1"
			drop _merge
				display "2"
			replace weight`w'=1 if sib==1&years_rel_birth==-5&phat`w'!=.
			display "3"
			save `main', replace
			display "4"
			use `list', clear
			display "5"
				drop _all
				display "6"
				gen id=""
				display "7"
				gen testyear=.
				display "8"
				gen series=.
				display "9"
			save `list', replace
			display "10"
		}
		
use `main', clear
sum weight*		

*forv w=3/17 {
foreach w in 6 7 23 24 {
	egen weight`w'_fe=sum(weight`w') if sib+mom==0, by(id)
	egen phat`w'_max=max(phat`w'), by(id)
	replace weight`w'_fe=1 if sib==1&phat`w'_max!=.
	drop phat`w'_max
	}
	
sum  missing_pct* if years_rel_birth==0&sib==1	
		
save "D:\Sibling Spillover\data\b_final_oldersibs", replace
