******************************
***Florida Sibling Analysis***
***Jenni Heissel**************
***July 25, 2014**************
***Analyzing FL Data**********
******************************
******************************

use "D:\Sibling Spillover\data\c_final.dta", clear
	set more off

drop if mom==1|sib==1
drop if oldest==1

***setting random
set seed 123
drop random
gen random=runiform()
sort random

tab weight23

preserve
	drop if weight23==.
	collapse (min) testyear, by(famid)
	egen count=count(famid)
	gen placebo1=0
	replace placebo1=1 if _n<=200
	tab testyear placebo1
	sort famid testyear
	tempfile temp
	save `temp'
restore

sort famid testyear
merge famid testyear using `temp'
replace placebo1=0 if placebo1==.
	replace years_rel_birth=-1 if placebo1==1
	egen placebo=max(placebo1), by(id)
	drop placebo1 _merge
	tab placebo if years_rel_birth==-1
	
***Creating matched synthetic control group
	eststo clear
*	local if "if mom+sib==0&seq==1|sib==1&seq==1"
*all main analysis to be the same population:
	local if "if missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003&placebo==0|missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003&placebo==1&years_rel_birth==-1"

***longitudinal matching
eststo: logit placebo i.age female famcount frl black pcti_famL1 pcti_famL2 pcti_famL3  missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 pctiL1 pctiL2 pctiL3  missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first `if'
estat ic
*limited:
eststo: logit placebo famcount frl black pcti_famL2  missing_pcti_famL1 missing_pcti_famL2 pctiL2  missing_pctiL3 first_school_pcti_first `if'
		predict phat223 `if'
		gen     phat224=phat223+grid_first*10 `if'
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\TA1_logit_placebo.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("Model 1" "Model 2") 
	eststo clear

**making group id's for sibs
	drop pop
	preserve
	**make a list of ids for siblings with data in year=0
	keep if placebo==1&years_rel_birth==-1
	bys id: gen pop = 1 if _n==1
	replace pop = sum(pop) 
	keep id pop
	collapse pop, by(id)
	tempfile pop
	save `pop', replace
	restore
	merge m:1 id using `pop'
	drop _merge
	egen maxpop = max(pop)
	local end = maxpop[1]
	drop maxpop
	
**making a list of IDs
preserve
	clear
	gen id=""
	gen testyear=.
	gen series=.
	tempfile list
	save `list', replace
restore

	tempfile main
	save `main', replace

	tab pop if pop==`end'

	forv w = 223/224 {
		forv i = 1/`end'	{
*		forv i = 1/5	{
			use `main', clear
			keep if placebo==0&phat`w'!=.|placebo==1&years_rel_birth==-1&pop==`i'&phat`w'!=.
			egen max_placebo=max(placebo)
			if max_placebo==0 {
				disp "w - i is "`w' `i'
				}
			else {	
				forv j = 1/5 {
				psmatch2 placebo, pscore(phat`w') neighbor(1) out(testyear) caliper(1)
				preserve
					keep if _weight==1 & placebo==0
					gen series=`j'*1000+`i'
					keep id testyear series
					append using `list'
					save `list', replace
				restore
				egen temp=max(_weight), by(id)
				drop if placebo==0&temp==1
				drop temp
					}
				disp "w - i is "`w' `i'
				}
			}
			use `list', clear
			collapse (count) series, by(id testyear)
			replace series=series/5
			rename series weight`w'
			gen n=_n
			egen id2=concat(id n)
			drop n
			save `list', replace
				*sidetrip to make weighted list of times relative to the matchesd year (i.e., years_rel_birth for all)
				preserve
					*make 8 obs per sample
					expand 8
					*make one for each year -5 to +2 relative to year 0 (year of match)
					sort id2 testyear
					by id2 testyear: generate long obs = _n
					rename (testyear weight`w') (testyear_match weight`w'_rel)
					gen years_rel_birth=obs-6
					*plus one b/c match occurs year before birth in regular, then 4 more for -5 total in older sibling
					gen  testyear=testyear_match+years_rel_birth+1
					tempfile temp
					save `temp'
					*add siblings, match to test scores by year
					use `main', clear
						keep id testyear years_rel_birth placebo phat`w'
						egen keep=max(phat`w'), by(id)
						keep if placebo==1&keep!=.
						drop phat`w' keep
						gen weight`w'_rel=1
						append using `temp'
						merge m:1 id testyear using `main'
						replace id2=id if id2==""
						replace placebo=0 if placebo==.
						drop yr*
						tab years_rel_birth if abs(years_rel_birth)<6, g(yr)
							rename yr1 yrm5
							rename yr2 yrm4
							rename yr3 yrm3
							rename yr4 yrm2
							rename yr5 yrm1
							rename yr6 yr0
							rename yr7 yr1
							rename yr8 yr2

							label variable  yrm5  "5 years before birth"
							label variable  yrm4  "4 years before birth"
							label variable  yrm3  "3 years before birth"
							label variable  yrm2  "2 years before birth"
							label variable  yrm1  "1 years before birth"
							label variable  yr0  "Year of birth"
							label variable  yr1  "1 years after birth"
							label variable  yr2  "2 years after birth"

							***added 7/9/17 to redo panel with new id: 
							drop if years_rel_birth==.
							***recreating panel
							drop panel
							sort id2
							egen panel = group( id2 )
							sort panel testyear
							quietly by panel testyear:  gen dup = cond(_N==1,0,_n)
							tab dup
							
							tsset panel testyear
							
					save "D:\Sibling Spillover\data\b_years_rel_birth_`w'_placebo", replace	
				restore
			merge 1:m id testyear using `main'
				display "1"
			drop _merge
				display "2"
			replace weight`w'=1 if placebo==1&years_rel_birth==-1&phat`w'!=.
			display "3"
			save `main', replace
			display "4"
			use `list', clear
			display "5"
				drop _all
				display "6"
				gen id=""
				display "7"
				gen testyear=.
				display "8"
				gen series=.
				display "9"
			save `list', replace
			display "10"
		}
		
use `main', clear
sum weight*		

forv w=223/224 {
	egen weight`w'_fe=sum(weight`w') if placebo==0, by(id)
	egen phat`w'_max=max(phat`w'), by(id)
	replace weight`w'_fe=1 if placebo==1&phat`w'_max!=.
	drop phat`w'_max
	}
	
sum  missing_pct* if years_rel_birth==0&placebo==1	
		
save "D:\Sibling Spillover\data\b_final_placebo", replace
