******************************
***Florida Sibling Analysis***
***Jenni Heissel**************
***July 25, 2014**************
***Analyzing FL Data**********
******************************
******************************

use "D:\Sibling Spillover\data\b_final_oldersibs.dta", clear
	set more off
	
foreach var of varlist female frl black first_school_frl first_school_black oldest col_ever col_ever_4yr col_degree col_degree_4yr {
	replace `var'=`var'*100
	}
	
***Table 1: Descriptive Statistics
	preserve
	***keeping only within 5 years
		*keep if years_rel_birth>=-5&years_rel_birth<=0|mom+sib==0
		collapse mom sib weight* pcti_first Age15Less Age16 Age17 fullpanel_2 hasyr0 panelreq female age_at_birth age_at_birth_cont famcount oldest frl frl_mean black first_school_pcti_first mathnp_first readnp_first first_school_frl first_school_black first_school_mathnp_first first_school_readnp_first age_dif age_dif_older age_dif_1younger age_dif_2younger age_dif_3pyounger, by(id)
	eststo clear
	local variables female age_at_birth_cont famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first 
		eststo: estpost sum `variables' if mom+sib==0
		
		sort sib
		eststo: estpost sum `variables' if sib==1

		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\TOther_summary_stats_oldersibs.rtf, ///
				main(mean) aux(sd) nonum nostar b(3) replace label onecell ///
				mtitle("Families without teen birth, all" "Teen mothers" "Siblings of teen mothers" "Families without teen birth, first-observed match" "Families without teen birth, trajectory match" ) 
	restore
	
**Synthetic control options - siblings
preserve
replace age_cont=age_cont+1
replace age=age+1
	eststo clear
	eststo: reg female if sib==1&weight23==1,  vce(cluster famid)  
	foreach i in 23 24 {
		eststo: reg female sib [aw=weight`i'],  vce(cluster famid) 
		}
			esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\T10_summary_stats_synthetic_oldersibs.rtf, ///
				se(3) scalars(p) nonum nostar b(3) replace label onecell nonotes ///
				keep(_cons) nogaps noline noobs  ///
				mtitle("Siblings" "Synthetic Control 3" "Synthetic Control 4" ///
								  "Synthetic Control 5" "Synthetic Control 6" "Synthetic Control 7" "Synthetic Control 8" "Synthetic Control 9") 
				
	foreach var of varlist age famcount frl black pcti_first pctiL3 pctiL2 pctiL1 pcti first_school_frl first_school_black first_school_pcti_first {
		eststo clear
		eststo: reg `var' if sib==1&weight23==1,  vce(cluster famid) 
	foreach i in 23 24 {
		*forv i=6/7 {
			eststo: reg `var' sib [aw=weight`i'],  vce(cluster famid) 
			}
				esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\T10_summary_stats_synthetic_oldersibs.rtf, ///
					se(3) scalars(p) nonum nostar b(3) append label onecell nonotes ///
					keep(_cons) nogaps noline noobs nomtitle 
				}
	eststo clear
	eststo: reg female if sib==1&weight23==1, vce(cluster famid)
	foreach i in 23 24 {
	*forv i=6/7 {
		eststo: reg female if sib==0 [aw=weight`i'],  vce(cluster famid) 
		}
			esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\T10_summary_stats_synthetic_oldersibs.rtf, ///
				se(3) nonum nostar b(3) append  onecell nonotes ///
				drop(_cons) nogaps noline  nomtitle 
restore

foreach var of varlist female frl black oldest  {
	replace `var'=`var'/100
	}
						
**************************
***OLDER SIBLINGS***
**************************			
***Table A6: Estimated Effects - OLDER SIBLINGS
**ROW 1: Test scores in grade 10
	eststo clear
	eststo: reg pct_10 sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight6], vce(cluster famid)
	eststo: reg pct_10 sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight23], vce(cluster famid)
	eststo: reg pct_10 sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight24], vce(cluster famid)
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\T10_sibling_outcomes_oldersib.rtf, ///
			title(Percentile rank - first-observed test score)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("IND" "IND+FAM" "IND+FAM+NBHD" ) ///
			keep(sib) nonotes 
foreach var of varlist  repeat dropout_ever jjc_ever col_ever col_degree col_degree_4yr {
**ROW 2+: Ever happened?
	eststo clear
	eststo: reg `var' sib female age_cont famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight6], vce(cluster famid)
	eststo: reg `var' sib female age_cont famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight23], vce(cluster famid)
	eststo: reg `var' sib female age_cont famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight24], vce(cluster famid)
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\T10_sibling_outcomes_oldersib.rtf, ///
			title(`var')	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
		}
